@@ -8,7 +8,6 @@
 #' @return \code{has_attributes} returns \code{TRUE} where \code{x} has
 #' the attributes specified in \code{attrs}. \code{assert_has_terms} returns nothing but throws
 #' an error if \code{has_terms} is not \code{TRUE}.
-#' @seealso \code{\link[stats]{terms.default}}.
 #' @examples
 #' x <- structure(c(a = 1), b = 2)
 #' assert_has_all_attributes(x, c("names", "b"))
@@ -21,10 +20,9 @@
 has_attributes <- function(x, attrs, .xname = get_name_in_parent(x))
 {
   if(is_empty(attrs)) return(logical())
-  vapply(
+  bapply(
     attrs,
-    function(at) is_not_null(attr(x, at)),
-    logical(1)
+    function(at) is_not_null(attr(x, at))
   )
 }
 
@@ -37,7 +35,6 @@ has_attributes <- function(x, attrs, .xname = get_name_in_parent(x))
 #' @return \code{has_terms} returns \code{TRUE} if \code{attributes(x)}
 #' has length zero. \code{assert_has_terms} returns nothing but throws
 #' an error if \code{has_terms} is not \code{TRUE}.
-#' @seealso \code{\link[stats]{terms.default}}.
 #' @examples
 #' assert_has_terms(lm(uptake ~ conc, CO2))
 #' @export
@@ -55,20 +52,41 @@ has_any_attributes <- function(x, .xname = get_name_in_parent(x))
 #' Checks to see if the current call has an argument with 
 #' the name given in the input.
 #'
-#' @param x Input to check.
-#' @return \code{has_arg} wraps \code{hasArg}, providing more
+#' @param x Argument to check. 
+#' @param fn Function to find the argument in.
+#' @return \code{has_arg} reimplements \code{\link[methods]{hasArg}}, 
+#' letting you choose the function to serach in, and providing more
 #' information on failure.  
 #' @note There is currently no corresponding \code{assert_has_arg}
 #' function, because evaluating in the correct call is hard.
-#' @seealso \code{\link{ncol}}.
+#' @seealso \code{\link[methods]{hasArg}}.
 #' @examples
-#' assert_has_rows(data.frame(x = 1:10))
-#' assert_has_cols(matrix())
+#' has_arg(x, mean.default)
+#' has_arg(y, mean.default)   
+#' f <- function(...) has_arg(z)   
+#' f(z = 123)
+#' f(123)
 #' @export
-has_arg <- function(x)
+has_arg <- function(x, fn = sys.function(sys.parent()))
 {
-  ok <- eval.parent(substitute(hasArg(name), list(name = x)))
-  if(!ok) return(false("The argument doesn't exist in the current call."))
+  arg_name <- deparse(substitute(x))
+  formal_args_of_fn <- names(formals(fn))
+  if(!arg_name %in% formal_args_of_fn)
+  {                             
+    fn_name <- deparse(substitute(fn))
+    fail <- false("%s is not an argument of %s", sQuote(arg_name), sQuote(fn_name))
+    if("..." %in% formal_args_of_fn)
+    {
+      dots_call <- eval(quote(substitute(list(...))), sys.parent())
+      if(!arg_name %in% names(dots_call))
+      {
+         return(fail)
+      }
+    } else
+    {
+       return(fail)
+    }
+  }
   TRUE
 }
 
@@ -216,7 +234,7 @@ has_rows <- function(x)
 #' @return \code{has_terms} returns \code{TRUE} if the input has an 
 #' element or an attribute named terms. \code{assert_has_terms} returns 
 #' nothing but throws an error if \code{has_terms} is not \code{TRUE}.
-#' @seealso \code{\link[stats]{terms.default}}.
+#' @seealso \code{\link{terms}}.
 #' @examples
 #' assert_has_terms(lm(uptake ~ conc, CO2))
 #' @export
